======
judson
======

Overview
--------

The judson project contains the judson function. This function creates a dictionary from two iterators of the same length using the howe project. The judson project is named for W. L. Judson, one of the inventors of the zipper.

Installation
------------

To install judson, you can use `pip`. Open your terminal and run:

.. code-block:: bash

    pip install judson

License
-------

This project is licensed under the MIT License.

Links
-----

* `Download <https://pypi.org/project/judson/#files>`_
* `Source <https://github.com/johannes-programming/judson>`_ 

Credits
-------
- Author: Johannes
- Email: johannes-programming@posteo.org

Thank you for using judson!